@@ -14,17 +14,28 @@
 #include <KPluginFactory>
 #include <QVBoxLayout>
 
-K_PLUGIN_CLASS_WITH_JSON(KDiskFreeWidget, "kcmdf.json")
+K_PLUGIN_CLASS_WITH_JSON(KDiskFreeWidget, "kcm_kdf.json")
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 KDiskFreeWidget::KDiskFreeWidget( QWidget *parent, const QVariantList &args )
         : KCModule( parent, args )
+#else
+KDiskFreeWidget::KDiskFreeWidget( QObject *parent, const KPluginMetaData &data)
+        : KCModule( parent, data)
+#endif
 {
     setButtons(Help);
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     QVBoxLayout *topLayout = new QVBoxLayout( this );
+#else
+    QVBoxLayout *topLayout = new QVBoxLayout( widget() );
+#endif
     topLayout->setContentsMargins({});
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     mKdf = new KDFWidget( this, false );
+#else
+    mKdf = new KDFWidget( widget(), false );
+#endif
     topLayout->addWidget( mKdf );
 }
 
@@ -32,11 +43,11 @@ KDiskFreeWidget::~KDiskFreeWidget()
 {
     mKdf->applySettings();
 }
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 QString KDiskFreeWidget::quickHelp() const
 {
     return i18n("A right mouse button click opens a context menu to mount/unmount a device"
                 " or to open it in the file manager.");
 }
-
+#endif
 #include "kcmdf.moc"
